# In order to use the notify system, add or remove nicks to or from the
# notify_list variable using /append and /remove.  If you need instructions on
# how to use those two commands, run /doc global.tcl
# NOTE: The notify system is functional, but incomplete.  If you notice any odd
# behaviour, let me know (patearl@pobox.com).

# VARIABLES

# notify_list (Default: <empty>)
#     The list of people that you want to be notified about when they come
#     online or go offline.  Use /append and /remove to change this list.
if { [info vars ::dynamic::notify_list]=="" } { set ::dynamic::notify_list "" }

# notify_time (Default: 30000)
#     The time in milliseconds between notify checks.  I wouldn't set this too
#     low or you could lag or flood yourself off IRC.
if { [info vars ::dynamic::notify_time]=="" } { set ::dynamic::notify_time 30000 }

# notify_nicks (Default: 15)
#     The max number of nicks to send in a single ison request.
if { [info vars ::dynamic::notify_nicks]=="" } { set ::dynamic::notify_nicks 15 }

#-Clear out the onnow list on connect

set ::[index]::onnow ""
set ::[index]::checking ""
set ::[index]::checkingtag ""

#-When people are removed from the notify list, make sure to remove them from
#-the online list too.  How do I do this now?

#-See about auto-store variable so that store is called every time an option
#-is changed.  Right now, would affect /alias, /set, /unset, /append, /remove.

#-DAL watch

#-Append on some server specific notify list perhaps

#-Call NOTIFY_SIGNON and NOTIFY_SIGNOFF when events occur
#-Add generic proc to call events with certain arguments


proc event_unload {} {
    after cancel "if { \[info commands ::[index]::notify::checknotify]!=\"\" } { ::[index]::notify::checknotify }"
}

proc event_pong { prefix args } {
    if { [string match "NOTIFY_TAG_*" [lindex $args 1]] } {
	set ::[index]::checkingtag [lindex $args 1]
	return 3
    }
    return 0
}

proc event_quit { prefix args } {
    set oldnick [lindex [split $prefix "!"] 0]
    if { [lsearch -exact [set ::[index]::onnow] $oldnick]!=-1 } {
	set index [lsearch -exact [set ::[index]::onnow] $oldnick]
	set ::[index]::onnow [lreplace [set ::[index]::onnow] $index $index]
	echo " \0030,7 NOTIFY \003 $oldnick signed off." [pathname status]
    }
    return 0
}

proc event_join { prefix args } {
    set newnick [lindex [split $prefix "!"] 0]
    if { [lsearch -exact $::dynamic::notify_list $newnick]!=-1 && [lsearch -exact [set ::[index]::onnow] $newnick]==-1 } {
	lappend ::[index]::onnow $newnick
	echo " \0030,7 NOTIFY \003 $newnick signed on." [pathname status]
    }
    return 0
}

proc event_nick { prefix newnick } {
    set oldnick [lindex [split $prefix "!"] 0]
    if { [lsearch -exact [set ::[index]::onnow] $oldnick]!=-1 } {
	set index [lsearch -exact [set ::[index]::onnow] $oldnick]
	set ::[index]::onnow [lreplace [set ::[index]::onnow] $index $index]
	echo " \0030,7 NOTIFY \003 $oldnick signed off." [pathname status]
    }
    if { [lsearch -exact $::dynamic::notify_list $newnick]!=-1 && [lsearch -exact [set ::[index]::onnow] $newnick]==-1 } {
	lappend ::[index]::onnow $newnick
	echo " \0030,7 NOTIFY \003 $newnick signed on." [pathname status]
    }
    return 0
}

proc event_303 { prefix args } {
    if { [set ::[index]::checkingtag]!="" } {
	set newnicks [split [string trim [lindex $args 1]]]
	foreach nick $newnicks {
	    if { [lsearch -exact [set ::[index]::onnow] $nick]==-1 } {
		lappend ::[index]::onnow $nick
		echo " \0030,7 NOTIFY \003 $nick signed on." [pathname status]
	    }
	}
	set index [lsearch -exact [set ::[index]::checking] [set ::[index]::checkingtag]]
	set oldnicks [lindex [set ::[index]::checking] [expr $index+1]]
	set ::[index]::checking [lreplace [set ::[index]::checking] $index [expr $index+1]]
	foreach nick $oldnicks {
	    if { [lsearch -exact $newnicks $nick]==-1 && [lsearch -exact [set ::[index]::onnow] $nick]!=-1 } {
		set index [lsearch -exact [set ::[index]::onnow] $nick]
		set ::[index]::onnow [lreplace [set ::[index]::onnow] $index $index]
		echo " \0030,7 NOTIFY \003 $nick signed off." [pathname status]
	    }
	}
	set ::[index]::checkingtag ""
	return 3
    }
    return 0
}

proc checknotify {} {
    set checksection 0
    while { [llength [set nicks [lrange [set ::dynamic::notify_list] $checksection [expr $checksection+$::dynamic::notify_nicks-1]]]] } {
	incr checksection $::dynamic::notify_nicks
	set tag "NOTIFY_TAG_[microtime]"
	lappend ::[index]::checking $tag
	lappend ::[index]::checking $nicks
	quote "PING $tag"
	quote "ISON [join $nicks]"
    }
    after $::dynamic::notify_time "if { \[info commands ::[index]::notify::checknotify]!=\"\" } { ::[index]::notify::checknotify }"
}

::[index]::notify::checknotify

#-If userhosts are desired (make config option) then send them in bunches
#-of 5 as the isons come in.  There is some posibility of "nick not found"
#-junk if the nicks go ofline.

#Usage: NOTIFY [[-]<nickname> [[-]<nickname> ...]]
#-  Use of this command lets you mark certain nicknames such that
#-  you will be warned when they signon or off of IRC.  When
#-  someone on your notify-list signs on, you will see a message
#-    *** Signon by <nickname> detected
#-  Likewise, when they signoff, you will see
#-    *** Signoff by <nickname> detected
#-  Someone will be shown as signed off if they change nicknames as well,
#-  so keep this in mind.
#-
#-  You can modify how the signon and signoff messages are
#-  displayed using the ON NOTIFY_SIGNON and ON NOTIFY_SIGNOFF
#-  commands.
#-
#-  Specifying a - before a nickname will remove notification
#-  checking for that nickname.  If no parameters are specified,
#-  the current status of each user on your notify list is
#-  displayed.  If you specify a + without any additional
#-  parameters:
#-    NOTIFY +
#-  you will be shown a list of only those people on your
#-  notification list who are currently on irc.  If you specify
#-  a - with no additional parameters, all nicks will be removed.
