proc ::to_char { value } {
    return [format %c $value]
}

proc ::from_char { char } {
    scan $char %c value
    return $value
}

proc ::decimal { char } {
    set number [from_char $char]
    if { $number>=[from_char "0"] && $number<=[from_char "9"] } {
	return [expr $number-48];
    }
    if { $number>=[from_char "a"] && $number<=[from_char "z"] } {
	return [expr $number-87];
    }
    if { $number>=[from_char "A"] && $number<=[from_char "Z"] } {
	return [expr $number-55];
    }
    error "Invalid character given to convert to a decimal!"
}

proc ::actual { decimal } {
    if { $decimal<0 || $decimal>35 } {
	error "Invalid decimal givem to convert to a character!"
    } else {
	if { $decimal>9 } {
	    return [to_char [expr $decimal+55]]
	} else {
	    return $decimal
	}
    }
}

proc ::base { number base newbase } {
    if { $base<2 || $base>36 || $newbase<2 || $newbase>36 } {
	error "Valid bases are between 2 and 36."
    }
    set total 0
    for { set c 0 } { $c < [string length $number] } { incr c } {
	set total [expr $total+[decimal [string index $number $c]]*int(pow($base,[string length $number]-$c-1))]
    }
    set outputstring ""
    while { $total!=0 } {
	set remainder [expr $total%$newbase]
	set total [expr $total/$newbase]
	set tempstring [actual $remainder]
	append tempstring $outputstring
	set outputstring $tempstring
    }
    return $outputstring
}

proc convert_from_morse { data } {
    regsub -all -nocase -- " \\.- " $data a data
    regsub -all -nocase -- " -\\.\\.\\. " $data b data
    regsub -all -nocase -- " -\\.-\\. " $data c data
    regsub -all -nocase -- " -\\.\\. " $data d data
    regsub -all -nocase -- " \\. " $data e data
    regsub -all -nocase -- " \\.\\.-\\. " $data f data
    regsub -all -nocase -- " --\\. " $data g data
    regsub -all -nocase -- " \\.\\.\\.\\. " $data h data
    regsub -all -nocase -- " \\.\\. " $data i data
    regsub -all -nocase -- " \\.--- " $data j data
    regsub -all -nocase -- " -\\.- " $data k data
    regsub -all -nocase -- " \\.-\\.\\. " $data l data
    regsub -all -nocase -- " -- " $data m data
    regsub -all -nocase -- " -\\. " $data n data
    regsub -all -nocase -- " --- " $data o data
    regsub -all -nocase -- " \\.--\\. " $data p data
    regsub -all -nocase -- " --\\.- " $data q data
    regsub -all -nocase -- " \\.-\\. " $data r data
    regsub -all -nocase -- " \\.\\.\\. " $data s data
    regsub -all -nocase -- " - " $data t data
    regsub -all -nocase -- " \\.\\.- " $data u data
    regsub -all -nocase -- " \\.\\.\\.- " $data v data
    regsub -all -nocase -- " \\.-- " $data w data
    regsub -all -nocase -- " -\\.\\.- " $data x data
    regsub -all -nocase -- " -\\.-- " $data y data
    regsub -all -nocase -- " --\\.\\. " $data z data
    return $data
}

proc convert_to_morse { data } {
    regsub -all -nocase -- a $data " .- " data
    regsub -all -nocase -- b $data " -... " data
    regsub -all -nocase -- c $data " -.-. " data
    regsub -all -nocase -- d $data " -.. " data
    regsub -all -nocase -- e $data " . " data
    regsub -all -nocase -- f $data " ..-. " data
    regsub -all -nocase -- g $data " --. " data
    regsub -all -nocase -- h $data " .... " data
    regsub -all -nocase -- i $data " .. " data
    regsub -all -nocase -- j $data " .--- " data
    regsub -all -nocase -- k $data " -.- " data
    regsub -all -nocase -- l $data " .-.. " data
    regsub -all -nocase -- m $data " -- " data
    regsub -all -nocase -- n $data " -. " data
    regsub -all -nocase -- o $data " --- " data
    regsub -all -nocase -- p $data " .--. " data
    regsub -all -nocase -- q $data " --.- " data
    regsub -all -nocase -- r $data " .-. " data
    regsub -all -nocase -- s $data " ... " data
    regsub -all -nocase -- t $data " - " data
    regsub -all -nocase -- u $data " ..- " data
    regsub -all -nocase -- v $data " ...- " data
    regsub -all -nocase -- w $data " .-- " data
    regsub -all -nocase -- x $data " -..- " data
    regsub -all -nocase -- y $data " -.-- " data
    regsub -all -nocase -- z $data " --.. " data
    return $data
}

proc rot13_char { char } {
    scan $char %c value
    if { $value>=0x41 && $value<=0x5a } {
	return [format %c [expr ((($value-0x41)+13)%26)+0x41]]
    }
    if { $value>=0x61 && $value<=0x7a } {
	return [format %c [expr ((($value-0x61)+13)%26)+0x61]]
    }
    return $char
}

proc char_to_hex { char } {
    scan $char %c value
    return "[format %x [expr $value/16]][format %x [expr $value%16]]"
}

proc hex_to_char { data } {
    if { [string length $data]!=2 } { return "*" }
    scan [string index $data 0] %x first
    scan [string index $data 1] %x second
    return [format %c [expr $first*16+$second]]
}

proc char_to_binary { char } {
    set returnvalue ""
    scan $char %c value
    for { set n 7 } { $n >= 0 } { incr n -1 } {
	if { [expr int(pow(2,$n))&$value] } {
	    append returnvalue "1"
	} else {
	    append returnvalue "0"
	}
    }
    return $returnvalue
}

proc binary_to_char { data } {
    set returnvalue 0
    for { set n 7 } { $n >= 0 } { incr n -1 } {
        if { [string index $data [expr 7-$n]]=="0" || [string index $data [expr 7-$n]]=="1" } {
	    set returnvalue [expr $returnvalue+[string index $data [expr 7-$n]]*int(pow(2,$n))]
	} else {
	    return "*"
	}
    }
    return [format %c $returnvalue]
}

proc alias_binary { arg } {
    set thedata "BinaryData:: "
    for { set n 0 } { $n < [string length $arg] } { incr n } {
	append thedata [char_to_binary [string index $arg $n]]
    }
    say $thedata
}

proc alias_hex { arg } {
    set thedata "HexData:: "
    for { set n 0 } { $n < [string length $arg] } { incr n } {
	append thedata [char_to_hex [string index $arg $n]]
    }
    say $thedata
}

proc alias_rot13 { arg } {
    set thedata "Rot13Data:: "
    for { set n 0 } { $n < [string length $arg] } { incr n } {
	append thedata [rot13_char [string index $arg $n]]
    }
    say $thedata
}

proc alias_morse { arg } {
    say "M2:: [convert_to_morse $arg]"
}

proc event_privmsg { prefix args } {
    if { [string match "BinaryData\:\: *" [lindex $args 1]] } {
        set returnvalue "<[lindex [split $prefix "!"] 0]> "
	set rest [string range [lindex $args 1] 13 [expr [string length [lindex $args 1]]-1]]
        while { $rest!="" } {
	    append returnvalue [binary_to_char [string range $rest 0 7]]
	    set rest [string range $rest 8 [expr [string length [lindex $args 1]]-1]]
	}
	echo [currentwindow] 0 " \0030,7 BINARY \003 $returnvalue"
    }
    if { [regexp "^HexData\:\: \[0-9a-fA-f]*" [lindex $args 1]] } {
        set returnvalue "<[lindex [split $prefix "!"] 0]> "
	set rest [string range [lindex $args 1] 10 [expr [string length [lindex $args 1]]-1]]
        while { $rest!="" } {
	    append returnvalue [hex_to_char [string range $rest 0 1]]
	    set rest [string range $rest 2 [expr [string length [lindex $args 1]]-1]]
	}
	echo [currentwindow] 0 " \0030,7 HEX \003 $returnvalue"
    }
    if { [string match "Rot13Data\:\: *" [lindex $args 1]] } {
        set returnvalue "<[lindex [split $prefix "!"] 0]> "
	set rest [string range [lindex $args 1] 12 [expr [string length [lindex $args 1]]-1]]
        while { $rest!="" } {
	    append returnvalue [rot13_char [string index $rest 0]]
	    set rest [string range $rest 1 [expr [string length [lindex $args 1]]-1]]
	}
	echo [currentwindow] 0 " \0030,7 ROT13 \003 $returnvalue"
    }
    if { [string match "M2\:\: *" [lindex $args 1]] } {
        set returnvalue "<[lindex [split $prefix "!"] 0]> "
	set rest [string range [lindex $args 1] 5 [expr [string length [lindex $args 1]]-1]]
	echo [currentwindow] 0 " \0030,7 MORSE \003 [convert_from_morse $rest]"
    }
}
