# This is the file that contains a number of the default configuration
# variables for QuIRC along with their default settings.  If you
# /loadglobal variables.tcl it will set all the variables contained in this
# file to their default values.  It may be useful to do this after upgrading
# in case some variables have changed and things no longer work properly with
# the old values.  See /doc global.tcl for information on how to manipulate
# these variables.  If somebody wants to write a GUI configuration system for
# the variables contained in this file, that'd be great.  If you do, be sure to
# let me know so I can include it in the distribution and I can update you on
# any variables that are added or removed in the future.


# IDENTITY/SERVER SETTINGS

# default_nick (Default: QuIRCy)
#     The default nick (alias) you will use on IRC.
set ::dynamic::default_nick QuIRCy

# default_altnick1 (Default: QuIRCyOne)
#     This is the nick QuIRC will attempt to use if default_nick is taken.
set ::dynamic::default_altnick1 QuIRCyOne

# default_altnick2 (Default: QuIRCyTwo)
#     This is the nick QuIRC will attempt to use if default_altnick1 is taken.
set ::dynamic::default_altnick2 QuIRCyTwo

# default_user (Default: quirc)
#     The user part of nick!~user@host.  This setting will show up if ident
#     does not respond or the ident response is not used.
set ::dynamic::default_user quirc

# default_desc (Default: QuIRC User)
#     The "real name" part of the whois and finger replies.
set ::dynamic::default_desc "QuIRC User"

# default_server (Default: irc.dal.net)
#     The IRC server that QuIRC will use upon startup.
set ::dynamic::default_server "irc.dal.net"

# default_port (Default: 6667)
#     The port that QuIRC will try to connect to the IRC server on unless
#     another port number is explicitely specified.
set ::dynamic::default_port 6667

# default_quit (Default: QuIRC for *nix - http://quirc.org/)
#     The quit message that is used unless another one is explicitely
#     specified.
set ::dynamic::default_quit "QuIRC for *nix - http://quirc.org/"

# autoconnect (Default: 1)
#     If this is set to 1, QuIRC will start the connection process
#     automatically when a new server is started.  Set to 0 to disable.
set ::dynamic::autoconnect 1

# rename_servers (Default: 1)
#     If this variable is set to 1, it will rename the status window based on
#     certain responses from the server.  Set to 0 to disable.
set ::dynamic::rename_servers 1

# auto_rejoin (Default: 1)
#     Automatically rejoin previously joined channels when reconnecting to a
#     server.
set ::dynamic::auto_rejoin 1

# max_modes (Default: 3)
#     The maximum number of mode changes QuIRC will send at a single time.
set ::dynamic::max_modes 3

# CLIENT SETTINGS

# first_time (Default: 1)
#     This variable is used to detect if instructions should be given on how to
#     set QuIRC up for the first time.  Set it to 0 to disable them.  This
#     variable also disables autoconnect.
set ::dynamic::first_time 1

# defaultgeometry (Default: 600x400)
#     This is the geometry the client will use initially.  When you use
#     /store, the contents of this variable are overwritten by the current
#     position and size of the QuIRC window.
set ::dynamic::defaultgeometry 600x400+10+10

# do_rawview (Default: 1)
#     The variable that determines if raw output/input will be sent to the
#     rawview window which is accessed with /rawview.
set ::dynamic::do_rawview 1

# lag_time (Default: 10)
#     The lag checking frequency in seconds.  Set it to 0 to disable the lag
#     checker.
set ::dynamic::lag_time 10

# theme (Default: style.tcl)
#     The tcl file that controls what the majority of the stuff in QuIRC looks
#     like.  It controls output and colors and such.
set ::dynamic::theme style.tcl

# default_scripts (Default: default.tcl dal.tcl translate.tcl popups.tcl fun.tcl notify.tcl)
#     The scripts in this listing are automatically loaded when a new server
#     is started.  The filenames should all be relative to ~/.quirc/.
#     NOTE:  The theme file will be loaded before the scripts in this list.
set ::dynamic::default_scripts "default.tcl dal.tcl translate.tcl popups.tcl fun.tcl notify.tcl"

# default_globalscripts (Default: global.tcl country.tcl)
#     The scripts in this listing are automatically loaded at the start of the
#     client into the global namespace.  Use filenames relative to ~/.quirc/.
#     NOTE:  The theme file will be loaded before the scripts in this list.
set ::dynamic::default_globalscripts "global.tcl country.tcl popups.tcl"

# nick_complete_seperator (Default ":")
#     The seperator used after the nick at the beginning of a line for nick
#     complete.
set ::dynamic::nick_complete_seperator ":"

# nick_complete_postfix (Default " ")
#     The string inserted after the end of a completed nick.
set ::dynamic::nick_complete_postfix " "

# echo_services_to_status (Default: 0)
#     Set this to 1 if you want message from NickServ, ChanServ, and MemoServ
#     to go to the server status window.
set ::dynamic::echo_services_to_status 0

# DCC/CTCP SETTINGS

# dcc_auto_accept (Default: 0)
#     This will make QuIRC auto-accept DCC file requests.  This however will
#     not make it automatically overwrite or rename.  There are other variables
#     for that.
set ::dynamic::dcc_auto_accept 0

# dcc_auto_overwrite (Default: 0)
#     If dcc_auto_accept is set, but the file exists, setting this variable
#     will cause it to automatically be overwritten.
set ::dynamic::dcc_auto_overwrite 0

# dcc_packetsize (Default: 4096)
#     This is how big of a chunk to send at one time.  I've noticed that it
#     doesn't seem to send that big of a chunk anyways, but can always try.
set ::dynamic::dcc_packetsize 4096

# dcc_localip (Default: <empty>)
#     The IP to send in the DCC request.  This variable may be useful if the
#     auto-detected IP is incorrect.  If it is empty, the auto-detected ip
#     will be used.
set ::dynamic::dcc_localip ""

# dcc_directory (Default: $env(HOME))
#     The directory dcc files will automatically be recieved into.  Do not use
#     $env(HOME) in the /set command as it will not be interpreted as a
#     variable, instead use the actual path.
set ::dynamic::dcc_directory "$env(HOME)"

# dcc_statuswait (Default: 300)
#     The minimum time in milliseconds that dcc transfers will wait before
#     updating their stats in the dcc listbox.  This prevents the DCC from
#     lagging due to constantly updating the GUI.
set ::dynamic::dcc_statuswait 300

# default_ctcp_cloak (Default: 0)
#     This controls what the server specific (::idx::cloak) variable gets set
#     to when a new server is started.  If it is 1, all CTCP (including DCC)
#     messages will be ignored.
set ::dynamic::default_ctcp_cloak 0
